<template>
  <el-dialog
    :visible.sync="dialogVisible"
    @close="$emit('close-dialog')"
    @closed="closed"
    @open="open"
    title="人员选择"
    width="1250px"
    custom-class="user-select-dialog"
    top="7vh"
  >
    <div class="table-content">
      <div class="search-box">
        <el-form v-model="queryParams" :inline="true" label-suffix="：">
          <el-form-item label="姓名">
            <el-input
              :clearable="true"
              placeholder="请输入姓名"
              v-model="queryParams.fullname"
            />
          </el-form-item>
          <el-form-item label="手机号">
            <el-input
              :clearable="true"
              placeholder="请输入手机号"
              v-model="queryParams.mobile"
            />
          </el-form-item>
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">
              搜索
            </el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">
              重置
            </el-button>
          </el-form-item>
        </el-form>
      </div>
      <el-table
        v-loading="loading"
        border
        size="mini"
        :data="orgUserQueryData"
        :style="{width: '100%'}"
        max-height="450px"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        row-key="id"
        :row-class-name="tableRowClassName"
        @row-click="rowClick"
      >
        <el-table-column type="index" width="70" label="序号" align="center">
        </el-table-column>
        <el-table-column
          prop="fullname"
          show-overflow-tooltip
          align="center"
          label="姓名"
          min-width="150"
        />
        <el-table-column
          prop="mobile"
          show-overflow-tooltip
          align="center"
          label="手机号"
          min-width="150"
        />
        <el-table-column
          prop="sex"
          show-overflow-tooltip
          align="center"
          label="性别"
          min-width="150"
        />
      </el-table>
      <el-pagination
        align="right"
        background
        class="bbsl-pagination"
        ref="paginationPanel"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParams.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParams.pageSize"
        layout="total, prev, pager, next"
        :total="queryParams.total"
      ></el-pagination>
    </div>
    <i class="el-icon-right"></i>
    <div class="result-content">
      <div class="title">人员信息</div>
      <div class="info-box">
        <div class="row">
          <div class="item">
            <div class="label">姓名：</div>
            <div class="value">{{ rowInfo.fullname || '-' }}</div>
          </div>
        </div>
        <div class="row">
          <div class="item">
            <div class="label">手机号：</div>
            <div class="value">{{ rowInfo.mobile || '-' }}</div>
          </div>
        </div>
        <div class="row">
          <div class="item">
            <div class="label">性别：</div>
            <div class="value">{{ rowInfo.sex || '-' }}</div>
          </div>
        </div>
      </div>
    </div>
    <template v-slot:footer>
      <el-button
        type="primary"
        @click="handleSaveData"
      >
        保 存
      </el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </el-dialog>
</template>

<script>
import {orgUserQuery} from '@/api/device/resourceInspection/resourceInspection'

export default {
  name: 'UserSelectDialog',
  props: {
    userSelectDialog: {
      default: false,
      type: Boolean
    },
    userName: {
      default: '',
      type: String
    }
  },
  data() {
    return {
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        fullname: '',
        mobile: '',
        DEM_ID_: '1491618454686535680'
      },
      sorter: [
        {direction: 'DESC', property: 'updateTime'}
      ],
      orgUserQueryData: [],  // 用户列表
      loading: false,
      rowInfo: {
        fullname: ''
      }
    }
  },
  computed: {
    dialogVisible: {
      get() {
        return this.userSelectDialog
      },
      set(val) {
        this.$emit('update:userSelectDialog', val)
      }
    },
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = [
        {property: 'DEM_ID_', group: 'orgTree', operation: 'EQUAL'},
        {property: 'fullname', group: 'quick', operation: 'LIKE'},
        {property: 'mobile', group: 'quick', operation: 'LIKE'}
      ]
      const {pageSize, page, ...item} = this.queryParams
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          const value = item[i.property]
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          return {group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
    this.getOrgUserQuery()
  },
  methods: {
    // 弹层打开
    open() {
      this.getOrgUserQuery(rows => {
        this.rowInfo = rows.find(i => i.fullname === this.userName) || {}
      })
    },

    async getOrgUserQuery(callback = _ => _) {
      this.orgUserQueryData = []
      this.loading = true
      const {rows, total} = await orgUserQuery(this.computedQuery)
      this.orgUserQueryData = rows
      this.queryParams.total = total
      callback && callback(rows)
      this.loading = false
    },

    // 弹层关闭
    closed() {
      Object.assign(this.$data, this.$options.data())
    },

    // 保存
    handleSaveData() {
      if (!this.rowInfo.fullname) return this.$message.warning('请选择人员')
      const {fullname, mobile, id} = this.rowInfo
      this.$emit('userChange', {
        linkName: fullname,
        linkPhone: mobile,
        personId: id
      })
      this.dialogVisible = false
    },


    // 顶部搜索
    handleSearch() {
      this.queryParams.page = 1
      this.getOrgUserQuery()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.getOrgUserQuery()
    },

    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = page
      this.getOrgUserQuery()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageSize = pageSize
      this.getOrgUserQuery()
    },

    // 表格行点击
    rowClick(row) {
      this.rowInfo = row
    },

    //  行样式渲染
    tableRowClassName({row}) {
      const {fullname} = this.rowInfo
      if (
        row.fullname === fullname) {
        return 'row-active'
      }
    }

  }
}
</script>
<style lang="scss" scoped>
::v-deep .user-select-dialog {


  .el-dialog__body {
    display: flex;
    align-items: center;
    row-gap: 20px;
    column-gap: 30px;

    .table-content {
      display: flex;
      flex-direction: column;
      row-gap: 10px;
      height: 550px;
      position: relative;
      box-shadow: 0 0 8px 0 rgba(0, 0, 0, 0.1);
      padding: 20px;
      flex: 7.5;

      .row-active {
        transition: all 0.2s;
        background: #6fa1ff;


        .cell {
          color: #fff;
        }

        &:hover {
          .el-table__cell {
            background: #6fa1ff;
          }
        }
      }
    }

    > i {
      font-size: 30px;
    }

    .result-content {
      box-shadow: 0 0 8px 0 rgba(0, 0, 0, 0.1);
      padding: 20px;
      flex: 2.5;
      display: flex;
      flex-direction: column;
      row-gap: 30px;
      height: 550px;

      .title {
        font-size: 16px;
        font-weight: 600;
        color: #333;
      }

      .info-box {
        display: flex;
        flex-direction: column;
        row-gap: 10px;

        .row {
          display: flex;

          .item {
            display: flex;
            flex: 1;

            .label {
              flex: 2.5;
              font-size: 14px;
              color: #555;
            }

            .value {
              flex: 7.5;
              font-size: 14px;
              color: #606266;
            }
          }
        }
      }
    }
  }
}
</style>
